from .source import Source
from .boxnovel import BoxNovel
from .scribblehub import ScribbleHub
from .insanitycave import InsanityCave
from .kieshitl import KieshiTl
from .ktlchamber import Ktlchamber
from .lightnovelworld import LightNovelWorld
from .readlightnovel import ReadLightNovel
from .webnovel import Webnovel
from .wuxiaco import WuxiaCo
from .mtlnovel import MtlNovel
from .fanfiction import Fanfiction
from .novelfull import NovelFull

sources = [
    WuxiaCo,
    BoxNovel,
    ReadLightNovel,
    InsanityCave,
    Ktlchamber,
    LightNovelWorld,
    KieshiTl,
    ScribbleHub,
    MtlNovel,
    Fanfiction,
    NovelFull,
]